@@ -196,6 +196,10 @@ void ClientApp::OnBeforeChildProcessLaunch(
 
 void ClientApp::OnRenderProcessThreadCreated(
         CefRefPtr<CefListValue> extra_info) {
+#ifdef WIN32
+    auto pid = GetCurrentProcessId();
+    qDebug("ClientApp::OnRenderProcessThreadCreated: pid: %d\n", pid);
+#endif
     BrowserDelegateSet::iterator it = browser_delegates_.begin();
     for (; it != browser_delegates_.end(); ++it)
         (*it)->OnRenderProcessThreadCreated(this, extra_info);
@@ -203,6 +207,10 @@ void ClientApp::OnRenderProcessThreadCreated(
 
 void ClientApp::OnRenderThreadCreated(CefRefPtr<CefListValue> extra_info) {
     RenderDelegateSet::iterator it = render_delegates_.begin();
+#ifdef WIN32
+    auto pid = GetCurrentProcessId();
+    qDebug("ClientApp::OnRenderThreadCreated: pid: %d\n", pid);
+#endif
     for (; it != render_delegates_.end(); ++it)
         (*it)->OnRenderThreadCreated(this, extra_info);
 }
@@ -291,6 +299,10 @@ bool ClientApp::OnBeforeNavigation(CefRefPtr<CefBrowser> browser,
 void ClientApp::OnContextCreated(CefRefPtr<CefBrowser> browser,
                                  CefRefPtr<CefFrame> frame,
                                  CefRefPtr<CefV8Context> context) {
+#ifdef WIN32
+    auto pid = GetCurrentProcessId();
+    qDebug("ClientApp::OnContextCreated: pid: %d\n", pid);
+#endif
     CefRefPtr<CefV8Value> global = context->GetGlobal();
     CefRefPtr<CefV8Value> jcsound = CefV8Value::CreateObject(0);
     qDebug() << "CreateObject jcsound:" << jcsound;
