@@ -869,6 +869,7 @@ int CsoundEngine::runCsound()
 	csoundRegisterKeyboardCallback(ud->csound,
 								   &CsoundEngine::keyEventCallback,
                                    (void *) ud, CSOUND_CALLBACK_KBD_EVENT | CSOUND_CALLBACK_KBD_TEXT);
+	csoundKeyPress(getCsound(),'\0'); // necessary to put something into the buffer, otherwise sensekey complains when not started from terminal
 #else
 	csoundSetCallback(ud->csound,
 					  &CsoundEngine::keyEventCallback,
@@ -877,9 +878,9 @@ int CsoundEngine::runCsound()
 
 #ifdef QCS_RTMIDI
     if (!m_options.useCsoundMidi) {
-        csoundSetOption(ud->csound, "-+rtmidi=hostbased");
-        csoundSetOption(ud->csound, "-M0");
-        csoundSetOption(ud->csound, "-Q0");
+        csoundSetOption(ud->csound, const_cast<char *>("-+rtmidi=hostbased"));
+        csoundSetOption(ud->csound, const_cast<char *>("-M0"));
+        csoundSetOption(ud->csound, const_cast<char *>("-Q0"));
     }
 #endif
 
